from django.apps import AppConfig


class StacksContentGroupConfig(AppConfig):
    """Django app config for stacks-contentgroup."""

    name = 'stacks_contentgroup'
    verbose_name = "[Stacks] Content Group"
