.js-stacks-contentgroup-trigger {
    position: relative;
    z-index: 1000;
    cursor:pointer;
}

.js-contentgroup-content-outer {
    display:none;
}

.stacks-contentgroup .content-outer {
    clear:left;
    float:left;
    width:100%;
}
